<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>About</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.ui" line="33"/>
        <source>&amp;Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.ui" line="89"/>
        <source>&amp;Translators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.ui" line="145"/>
        <source>&amp;License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>YouTube%1 Browser for SMPlayer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="37"/>
        <source>Version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="39"/>
        <source>Portable Edition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Compiled with Qt %1 (using %2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="44"/>
        <source>Visit our website for updates:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="87"/>
        <source>Many people contributed with translations.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="88"/>
        <source>You can also help to translate SMTube into your own language.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="89"/>
        <source>Visit %1 and join a translation team.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="91"/>
        <source>Click here to know the translators from the transifex teams</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="117"/>
        <source>&lt;b&gt;%1&lt;/b&gt; (%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BrowserWindow</name>
    <message>
        <location filename="../browserwindow.cpp" line="125"/>
        <source>Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="128"/>
        <source>Navigation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="136"/>
        <source>Zoom +</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="140"/>
        <source>Zoom -</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="144"/>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="147"/>
        <source>&amp;Navigation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="159"/>
        <source>&amp;View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="160"/>
        <source>Toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="164"/>
        <source>Statusbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="168"/>
        <source>&amp;Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="176"/>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="179"/>
        <source>&amp;Update the YouTube code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="185"/>
        <source>About this &amp;release</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="190"/>
        <source>&amp;About SMTube</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="298"/>
        <source>Download video using an external service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="299"/>
        <source>Download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="527"/>
        <source>Connection failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="528"/>
        <source>The video you requested needs to open a HTTPS connection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="529"/>
        <source>Unfortunately the OpenSSL component, required for it, is not available in your system.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="534"/>
        <source>No video found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="535"/>
        <source>It wasn&apos;t possible to find the URL for this video.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="545"/>
        <location filename="../browserwindow.cpp" line="553"/>
        <source>Problems with YouTube</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="546"/>
        <location filename="../browserwindow.cpp" line="554"/>
        <source>Unfortunately due to changes in YouTube, the video &apos;%1&apos; can&apos;t be played.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="547"/>
        <source>Do you want to update the YouTube code? This may fix the problem.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="555"/>
        <source>Maybe updating this application could fix the problem.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="574"/>
        <source>About this release</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="575"/>
        <source>Due to changes in YouTube, the old SMTube doesn&apos;t work anymore.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="576"/>
        <source>This is a new version of SMTube, written from scratch.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="577"/>
        <source>Some functionality is not available yet.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="579"/>
        <source>Important:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="580"/>
        <source>If the VEVO videos fail to play, please use the option %1 in the Help menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="581"/>
        <source>Update the YouTube code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="284"/>
        <source>Loading... %1%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog.ui" line="14"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="27"/>
        <source>&amp;General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="108"/>
        <source>&amp;Players</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="156"/>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="121"/>
        <source>Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="33"/>
        <source>Playback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="39"/>
        <source>Preferred &amp;quality:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="167"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="191"/>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="204"/>
        <source>A&amp;dd predefined players</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="240"/>
        <source>&amp;Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="248"/>
        <source>&amp;Style:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="284"/>
        <source>Font:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="298"/>
        <source>C&amp;hange...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="68"/>
        <source>Download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="74"/>
        <source>Download videos using an &amp;external service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="132"/>
        <source>Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="74"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <location filename="../filechooser.cpp" line="56"/>
        <source>Click to select a file or folder</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MyWebView</name>
    <message>
        <location filename="../mywebview.cpp" line="37"/>
        <source>Open in &amp;YouTube</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="48"/>
        <source>&amp;Save link...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="51"/>
        <source>Copy &amp;link to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="52"/>
        <source>Open link in this window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="54"/>
        <source>&amp;Copy text to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="55"/>
        <source>Open link in &amp;new window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="79"/>
        <source>&amp;Play with</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="84"/>
        <source>Play &amp;audio with</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="137"/>
        <source>&amp;Play with %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="144"/>
        <source>Play &amp;audio with %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="151"/>
        <source>Play video with a &amp;web browser</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlayerDialog</name>
    <message>
        <location filename="../playerdialog.ui" line="14"/>
        <source>Edit Player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="22"/>
        <source>&amp;Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="39"/>
        <source>&amp;Executable:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="56"/>
        <source>&amp;Parameters:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="71"/>
        <source>This player supports &amp;video sites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="78"/>
        <source>This player can play &amp;online TV</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="87"/>
        <source>Preferred &amp;quality:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="117"/>
        <source>Add to &amp;menu:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="28"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="29"/>
        <source>Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="30"/>
        <source>Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="31"/>
        <source>Video and audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="33"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
